@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -74,7 +71,7 @@ g_mime_multipart_encrypted_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeMultipartEncrypted),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_multipart_encrypted_init,
 		};
 		
@@ -120,7 +117,7 @@ g_mime_multipart_encrypted_finalize (GObject *object)
 	g_free (mpe->protocol);
 	
 	if (mpe->decrypted)
-		g_mime_object_unref (mpe->decrypted);
+		g_object_unref (mpe->decrypted);
 	
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -154,7 +151,7 @@ multipart_encrypted_get_header (GMimeObject *object, const char *header)
 static void
 multipart_encrypted_remove_header (GMimeObject *object, const char *header)
 {
-	return GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
+	GMIME_OBJECT_CLASS (parent_class)->remove_header (object, header);
 }
 
 static void
@@ -191,12 +188,12 @@ multipart_encrypted_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * Returns an empty MIME multipart/encrypted object.
  **/
 GMimeMultipartEncrypted *
-g_mime_multipart_encrypted_new ()
+g_mime_multipart_encrypted_new (void)
 {
 	GMimeMultipartEncrypted *multipart;
 	GMimeContentType *type;
 	
-	multipart = g_object_new (GMIME_TYPE_MULTIPART_ENCRYPTED, NULL, NULL);
+	multipart = g_object_new (GMIME_TYPE_MULTIPART_ENCRYPTED, NULL);
 	
 	type = g_mime_content_type_new ("multipart", "encrypted");
 	g_mime_object_set_content_type (GMIME_OBJECT (multipart), type);
@@ -218,7 +215,7 @@ g_mime_multipart_encrypted_new ()
  * encrypted #GMimeObject is set as the encrypted part of the
  * multipart/encrypted object @mpe.
  *
- * Returns 0 on success or -1 on fail. If the encryption fails, an
+ * Returns %0 on success or %-1 on fail. If the encryption fails, an
  * exception will be set on @err to provide information as to why the
  * failure occured.
  **/
@@ -250,7 +247,7 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
 	
 	g_mime_object_write_to_stream (content, filtered_stream);
 	g_mime_stream_flush (filtered_stream);
-	g_mime_stream_unref (filtered_stream);
+	g_object_unref (filtered_stream);
 	
 	/* reset the content stream */
 	g_mime_stream_reset (stream);
@@ -258,12 +255,12 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
 	/* encrypt the content stream */
 	ciphertext = g_mime_stream_mem_new ();
 	if (g_mime_cipher_encrypt (ctx, FALSE, NULL, recipients, stream, ciphertext, err) == -1) {
-		g_mime_stream_unref (ciphertext);
-		g_mime_stream_unref (stream);
+		g_object_unref (ciphertext);
+		g_object_unref (stream);
 		return -1;
 	}
 	
-	g_mime_stream_unref (stream);
+	g_object_unref (stream);
 	g_mime_stream_reset (ciphertext);
 	
 	/* construct the version part */
@@ -274,25 +271,24 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
 	g_mime_object_set_content_type (GMIME_OBJECT (version_part), content_type);
 	
 	mpe->protocol = g_strdup (ctx->encrypt_protocol);
-	g_mime_object_ref (content);
 	mpe->decrypted = content;
+	g_object_ref (content);
 	
 	/* construct the encrypted mime part */
 	encrypted_part = g_mime_part_new_with_type ("application", "octet-stream");
 	wrapper = g_mime_data_wrapper_new ();
 	g_mime_data_wrapper_set_stream (wrapper, ciphertext);
-	g_mime_stream_unref (ciphertext);
+	g_object_unref (ciphertext);
 	g_mime_part_set_content_object (encrypted_part, wrapper);
-	g_mime_part_set_filename (encrypted_part, "encrypted.asc");
 	g_mime_part_set_encoding (encrypted_part, GMIME_PART_ENCODING_7BIT);
 	g_object_unref (wrapper);
 	
 	/* save the version and encrypted parts */
 	/* FIXME: make sure there aren't any other parts?? */
 	g_mime_multipart_add_part (GMIME_MULTIPART (mpe), GMIME_OBJECT (version_part));
-	g_mime_object_unref (GMIME_OBJECT (version_part));
+	g_object_unref (version_part);
 	g_mime_multipart_add_part (GMIME_MULTIPART (mpe), GMIME_OBJECT (encrypted_part));
-	g_mime_object_unref (GMIME_OBJECT (encrypted_part));
+	g_object_unref (encrypted_part);
 	
 	/* set the content-type params for this multipart/encrypted part */
 	g_mime_object_set_content_type_parameter (GMIME_OBJECT (mpe), "protocol", mpe->protocol);
@@ -335,7 +331,7 @@ g_mime_multipart_encrypted_decrypt (GMimeMultipartEncrypted *mpe, GMimeCipherCon
 	
 	if (mpe->decrypted) {
 		/* we seem to have already decrypted the part */
-		g_mime_object_ref (mpe->decrypted);
+		g_object_ref (mpe->decrypted);
 		return mpe->decrypted;
 	}
 	
@@ -343,7 +339,7 @@ g_mime_multipart_encrypted_decrypt (GMimeMultipartEncrypted *mpe, GMimeCipherCon
 	
 	if (protocol) {
 		/* make sure the protocol matches the cipher encrypt protocol */
-		if (g_strcasecmp (ctx->encrypt_protocol, protocol) != 0) {
+		if (g_ascii_strcasecmp (ctx->encrypt_protocol, protocol) != 0) {
 			g_set_error (err, GMIME_ERROR_QUARK, GMIME_ERROR_PROTOCOL_ERROR,
 				     "Failed to decrypt MIME part: protocol error");
 			
@@ -358,11 +354,11 @@ g_mime_multipart_encrypted_decrypt (GMimeMultipartEncrypted *mpe, GMimeCipherCon
 	
 	/* make sure the protocol matches the version part's content-type */
 	content_type = g_mime_content_type_to_string (version->content_type);
-	if (g_strcasecmp (content_type, protocol) != 0) {
+	if (g_ascii_strcasecmp (content_type, protocol) != 0) {
 		g_set_error (err, GMIME_ERROR_QUARK, GMIME_ERROR_PROTOCOL_ERROR,
 			     "Failed to decrypt MIME part: protocol error");
 		
-		g_mime_object_unref (version);
+		g_object_unref (version);
 		g_free (content_type);
 		
 		return NULL;
@@ -373,8 +369,8 @@ g_mime_multipart_encrypted_decrypt (GMimeMultipartEncrypted *mpe, GMimeCipherCon
 	encrypted = g_mime_multipart_get_part (GMIME_MULTIPART (mpe), GMIME_MULTIPART_ENCRYPTED_CONTENT);
 	mime_type = g_mime_object_get_content_type (encrypted);
 	if (!g_mime_content_type_is_type (mime_type, "application", "octet-stream")) {
-		g_mime_object_unref (encrypted);
-		g_mime_object_unref (version);
+		g_object_unref (encrypted);
+		g_object_unref (version);
 		return NULL;
 	}
 	
@@ -393,27 +389,28 @@ g_mime_multipart_encrypted_decrypt (GMimeMultipartEncrypted *mpe, GMimeCipherCon
 	
 	/* get the cleartext */
 	if (g_mime_cipher_decrypt (ctx, ciphertext, filtered_stream, err) == -1) {
-		g_mime_stream_unref (filtered_stream);
-		g_mime_stream_unref (ciphertext);
-		g_mime_stream_unref (stream);
+		g_object_unref (filtered_stream);
+		g_object_unref (ciphertext);
+		g_object_unref (stream);
 		
 		return NULL;
 	}
 	
 	g_mime_stream_flush (filtered_stream);
-	g_mime_stream_unref (filtered_stream);
-	g_mime_stream_unref (ciphertext);
+	g_object_unref (filtered_stream);
+	g_object_unref (ciphertext);
 	
+	g_mime_stream_reset (stream);
 	parser = g_mime_parser_new ();
 	g_mime_parser_init_with_stream (parser, stream);
-	g_mime_stream_unref (stream);
+	g_object_unref (stream);
 	
 	decrypted = g_mime_parser_construct_part (parser);
 	g_object_unref (parser);
 	
 	if (decrypted) {
 		/* cache the decrypted part */
-		g_mime_object_ref (decrypted);
+		g_object_ref (decrypted);
 		mpe->decrypted = decrypted;
 	} else {
 		g_set_error (err, GMIME_ERROR_QUARK, GMIME_ERROR_PARSE_ERROR,
